macro_rules! xdg_data_file {
($subpath: expr) => { ... };
}Expand description
Will create $“XDG_DATA_HOME”/<crate_name>/ and return the path to the file specified in $subpath
macro_rules! xdg_data_file {
($subpath: expr) => { ... };
}Will create $“XDG_DATA_HOME”/<crate_name>/ and return the path to the file specified in $subpath